@@ -1,5 +1,7 @@
 import base64
 import datetime
+import time
+import threading
 import xml.etree.ElementTree as ET
 
 import m3u8
@@ -51,6 +53,17 @@ class Client:
     """RadikoAPIにアクセスするためのクライアントクラス
     """
 
+    def auto_reload(self):
+        t = threading.currentThread()
+        while self.auto_reloading:
+            start = datetime.datetime.now()
+            target = datetime.datetime(year=start.year, month=start.month, day=start.day, hour=5, minute=0)
+            if start >= target:
+                target += datetime.timedelta(days=1)
+            duration = target - start
+            time.sleep(duration.total_seconds())
+            self.get_stations()
+
     def __init__(self):
         """
         
@@ -80,8 +93,12 @@ class Client:
             print(r.content)
             raise AuthError("認証2に失敗")
         self.area = r.content.decode().split(',')[0]
-
+        self.auto_reloading = True
         self.get_stations()
+        self.thread = []
+        t = threading.Thread(name="auto_reload", target=self.auto_reload)
+        t.setDaemon(True)
+        t.start()
 
     def get_stations(self):
         """受信可能な局一覧を取得する関数
@@ -219,4 +236,8 @@ class Prog:
         """
         if dt is None:
             dt = datetime.datetime.now()
-        return self.ft <= dt < self.to
\ No newline at end of file
+        return self.ft <= dt < self.to
+
+if __name__ == "__main__":
+    client = Client()
+    input()
